@@ -8,7 +8,7 @@
 
 set -ex
 
-PGVERSION=8.4
+: ${PGVERSION=$(pg_buildext supported-versions . | head -n 1)}
 
 MASTER_PORT=65432
 SLAVE_PORT=65433
@@ -58,7 +58,9 @@ pg_createcluster --port $SLAVE_PORT --start $PGVERSION slave
 su - postgres -c "createdb -p $MASTER_PORT $MASTER_DB"
 su - postgres -c "createdb -p $SLAVE_PORT $SLAVE_DB"
 
-su - postgres -c "createlang -p $MASTER_PORT plpgsql $MASTER_DB"
+case $PGVERSION in
+	8.*) su - postgres -c "createlang -p $MASTER_PORT plpgsql $MASTER_DB";;
+esac
 
 su - postgres -c "psql -p $MASTER_PORT -d $MASTER_DB -c 'CREATE TABLE testtable (a int PRIMARY KEY, b text);'"
 su - postgres -c "pg_dump --cluster $PGVERSION/master -s -p $MASTER_PORT $MASTER_DB | psql -p $SLAVE_PORT $SLAVE_DB"
